@@ -25,7 +25,7 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/config"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/docker"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/update"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
@@ -71,7 +71,7 @@ func TestCreateNewRunner(t *testing.T) {
 				Profiles:          []string{"unknown-profile"},
 			},
 			shouldErr:     true,
-			expectedError: "failed to apply profiles",
+			expectedError: `profile selection ["unknown-profile"] did not match those defined in any configurations`,
 		},
 		{
 			description: "unsupported trigger",
@@ -96,7 +96,7 @@ func TestCreateNewRunner(t *testing.T) {
 				return semver.Version{}, semver.Version{}, nil
 			})
 			t.NewTempDir().
-				Write("skaffold.yaml", fmt.Sprintf("apiVersion: %s\nkind: Config\n%s", latest.Version, test.config)).
+				Write("skaffold.yaml", fmt.Sprintf("apiVersion: %s\nkind: Config\n%s", latestV1.Version, test.config)).
 				Chdir()
 
 			_, _, _, err := createNewRunner(ioutil.Discard, test.options)
