@@ -18,6 +18,7 @@ package helm
 
 import (
 	"fmt"
+	"runtime"
 	"strconv"
 
 	"github.com/blang/semver"
@@ -26,7 +27,7 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
@@ -44,7 +45,7 @@ type installOpts struct {
 }
 
 // constructOverrideArgs creates the command line arguments for overrides
-func constructOverrideArgs(r *latest.HelmRelease, builds []graph.Artifact, args []string, record func(string)) ([]string, error) {
+func constructOverrideArgs(r *latestV1.HelmRelease, builds []graph.Artifact, args []string, record func(string)) ([]string, error) {
 	for _, k := range sortKeys(r.SetValues) {
 		record(r.SetValues[k])
 		args = append(args, "--set", fmt.Sprintf("%s=%s", k, r.SetValues[k]))
@@ -55,6 +56,8 @@ func constructOverrideArgs(r *latest.HelmRelease, builds []graph.Artifact, args
 		if err != nil {
 			return nil, fmt.Errorf("unable to expand %q: %w", r.SetFiles[k], err)
 		}
+		exp = sanitizeFilePath(exp, runtime.GOOS == "windows")
+
 		record(exp)
 		args = append(args, "--set-file", fmt.Sprintf("%s=%s", k, exp))
 	}
@@ -112,7 +115,7 @@ func getArgs(releaseName string, namespace string) []string {
 }
 
 // installArgs calculates the correct arguments to "helm install"
-func (h *Deployer) installArgs(r latest.HelmRelease, builds []graph.Artifact, valuesSet map[string]bool, o installOpts) ([]string, error) {
+func (h *Deployer) installArgs(r latestV1.HelmRelease, builds []graph.Artifact, valuesSet map[string]bool, o installOpts) ([]string, error) {
 	var args []string
 	if o.upgrade {
 		args = append(args, "upgrade", o.releaseName)
@@ -201,3 +204,53 @@ func (h *Deployer) installArgs(r latest.HelmRelease, builds []graph.Artifact, va
 
 	return args, nil
 }
+
+// sanitizeFilePath is used to sanitize filepaths that are provided to the `setFiles` flag
+// helm `setFiles` doesn't work with the unescaped filepath separator (\) for Windows or if there are unescaped tabs and spaces in the directory names.
+// So we escape all odd count occurrences of `\` for Windows, and wrap the entire string in quotes if it has spaces.
+// This is very specific to the way helm handles its flags.
+// See https://github.com/helm/helm/blob/d55c53df4e394fb62b0514a09c57bce235dd7877/pkg/cli/values/options.
+// Otherwise the windows `syscall` package implements its own sanitizing for command args that's used by `exec.Cmd`.
+// See https://github.com/golang/go/blob/6951da56b0ae2cd4250fc1b0350d090aed633ac1/src/syscall/exec_windows.go#L27
+func sanitizeFilePath(s string, isWindowsOS bool) string {
+	if len(s) == 0 {
+		return `""`
+	}
+	needsQuotes := false
+	for i := 0; i < len(s); i++ {
+		if s[i] == ' ' || s[i] == '\t' {
+			needsQuotes = true
+			break
+		}
+	}
+
+	if !isWindowsOS {
+		if needsQuotes {
+			return fmt.Sprintf(`"%s"`, s)
+		}
+		return s
+	}
+
+	var b []byte
+	slashes := 0
+	for i := 0; i < len(s); i++ {
+		switch s[i] {
+		case '\\':
+			slashes++
+		default:
+			// ensure a single slash is escaped
+			if slashes == 1 {
+				b = append(b, '\\')
+			}
+			slashes = 0
+		}
+		b = append(b, s[i])
+	}
+	if slashes == 1 {
+		b = append(b, '\\')
+	}
+	if needsQuotes {
+		return fmt.Sprintf(`"%s"`, string(b))
+	}
+	return string(b)
+}
