@@ -19,6 +19,8 @@ package helm
 import (
 	"fmt"
 
+	"github.com/pkg/errors"
+
 	deployerr "github.com/GoogleContainerTools/skaffold/pkg/skaffold/deploy/error"
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
 	"github.com/GoogleContainerTools/skaffold/proto/v1"
@@ -67,14 +69,7 @@ func helmLabelErr(err error) error {
 }
 
 func userErr(prefix string, err error) error {
-	if sErrors.IsSkaffoldErr(err) {
-		return err
-	}
-	return sErrors.NewError(err,
-		proto.ActionableErr{
-			Message: fmt.Sprintf("%s: %s", prefix, err.Error()),
-			ErrCode: proto.StatusCode_DEPLOY_HELM_USER_ERR,
-		})
+	return deployerr.UserError(errors.Wrap(err, prefix), proto.StatusCode_DEPLOY_HELM_USER_ERR)
 }
 
 func noMatchingBuild(image string) error {
