@@ -24,16 +24,16 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/docker"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/initializer/build"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/testutil"
 )
 
 type stubDeploymentInitializer struct {
-	config   latest.DeployConfig
-	profiles []latest.Profile
+	config   latestV1.DeployConfig
+	profiles []latestV1.Profile
 }
 
-func (s stubDeploymentInitializer) DeployConfig() (latest.DeployConfig, []latest.Profile) {
+func (s stubDeploymentInitializer) DeployConfig() (latestV1.DeployConfig, []latestV1.Profile) {
 	return s.config, s.profiles
 }
 
@@ -61,8 +61,8 @@ func (s stubBuildInitializer) PrintAnalysis(io.Writer) error {
 	panic("no sir")
 }
 
-func (s stubBuildInitializer) BuildConfig() (latest.BuildConfig, []*latest.PortForwardResource) {
-	return latest.BuildConfig{
+func (s stubBuildInitializer) BuildConfig() (latestV1.BuildConfig, []*latestV1.PortForwardResource) {
+	return latestV1.BuildConfig{
 		Artifacts: build.Artifacts(s.artifactInfos),
 	}, nil
 }
@@ -74,25 +74,25 @@ func (s stubBuildInitializer) GenerateManifests(io.Writer, bool) (map[build.Gene
 func TestGenerateSkaffoldConfig(t *testing.T) {
 	tests := []struct {
 		name                   string
-		expectedSkaffoldConfig *latest.SkaffoldConfig
-		deployConfig           latest.DeployConfig
-		profiles               []latest.Profile
+		expectedSkaffoldConfig *latestV1.SkaffoldConfig
+		deployConfig           latestV1.DeployConfig
+		profiles               []latestV1.Profile
 		builderConfigInfos     []build.ArtifactInfo
 		getWd                  func() (string, error)
 	}{
 		{
 			name:               "empty",
 			builderConfigInfos: []build.ArtifactInfo{},
-			deployConfig:       latest.DeployConfig{},
+			deployConfig:       latestV1.DeployConfig{},
 			getWd: func() (s string, err error) {
 				return filepath.Join("rootDir", "testConfig"), nil
 			},
-			expectedSkaffoldConfig: &latest.SkaffoldConfig{
-				APIVersion: latest.Version,
+			expectedSkaffoldConfig: &latestV1.SkaffoldConfig{
+				APIVersion: latestV1.Version,
 				Kind:       "Config",
-				Metadata:   latest.Metadata{Name: "testconfig"},
-				Pipeline: latest.Pipeline{
-					Deploy: latest.DeployConfig{},
+				Metadata:   latestV1.Metadata{Name: "testconfig"},
+				Pipeline: latestV1.Pipeline{
+					Deploy: latestV1.DeployConfig{},
 				},
 			},
 		},
@@ -106,41 +106,41 @@ func TestGenerateSkaffoldConfig(t *testing.T) {
 					ImageName: "image1",
 				},
 			},
-			deployConfig: latest.DeployConfig{},
+			deployConfig: latestV1.DeployConfig{},
 			getWd: func() (s string, err error) {
 				return string(filepath.Separator), nil
 			},
-			expectedSkaffoldConfig: &latest.SkaffoldConfig{
-				APIVersion: latest.Version,
+			expectedSkaffoldConfig: &latestV1.SkaffoldConfig{
+				APIVersion: latestV1.Version,
 				Kind:       "Config",
-				Metadata:   latest.Metadata{},
-				Pipeline: latest.Pipeline{
-					Build: latest.BuildConfig{
-						Artifacts: []*latest.Artifact{
+				Metadata:   latestV1.Metadata{},
+				Pipeline: latestV1.Pipeline{
+					Build: latestV1.BuildConfig{
+						Artifacts: []*latestV1.Artifact{
 							{
 								ImageName: "image1",
 								Workspace: "testDir",
-								ArtifactType: latest.ArtifactType{
-									DockerArtifact: &latest.DockerArtifact{DockerfilePath: "Dockerfile"},
+								ArtifactType: latestV1.ArtifactType{
+									DockerArtifact: &latestV1.DockerArtifact{DockerfilePath: "Dockerfile"},
 								},
 							},
 						},
 					},
-					Deploy: latest.DeployConfig{},
+					Deploy: latestV1.DeployConfig{},
 				},
 			},
 		},
 		{
 			name:               "error working dir",
 			builderConfigInfos: []build.ArtifactInfo{},
-			deployConfig:       latest.DeployConfig{},
+			deployConfig:       latestV1.DeployConfig{},
 			getWd: func() (s string, err error) {
 				return "", errors.New("testError")
 			},
-			expectedSkaffoldConfig: &latest.SkaffoldConfig{
-				APIVersion: latest.Version,
+			expectedSkaffoldConfig: &latestV1.SkaffoldConfig{
+				APIVersion: latestV1.Version,
 				Kind:       "Config",
-				Metadata:   latest.Metadata{},
+				Metadata:   latestV1.Metadata{},
 			},
 		},
 	}
