@@ -129,10 +129,10 @@ func TestLogAggregatorZeroValue(t *testing.T) {
 	var m *LogAggregator
 
 	// Should not raise a nil dereference
-	m.StartLogger(context.Background(), nil, []string{})
+	m.Start(context.Background(), []string{})
 	m.Mute()
 	m.Unmute()
-	m.StopLogger()
+	m.Stop()
 }
 
 func TestPrefix(t *testing.T) {
@@ -188,7 +188,7 @@ func TestPrefix(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			logger := NewLogAggregator(nil, nil, &mockConfig{log: latestV1.LogsConfig{
+			logger := NewLogAggregator(nil, nil, nil, nil, &mockConfig{log: latestV1.LogsConfig{
 				Prefix: test.prefix,
 			}})
 
