@@ -42,6 +42,7 @@ var (
 const Windows string = "windows"
 
 type Runner struct {
+	cfg        docker.Config
 	customTest latestV1.CustomTest
 	imageName  string
 	workspace  string
@@ -50,6 +51,7 @@ type Runner struct {
 // New creates a new custom.Runner.
 func New(cfg docker.Config, imageName string, ws string, ct latestV1.CustomTest) (*Runner, error) {
 	return &Runner{
+		cfg:        cfg,
 		imageName:  imageName,
 		customTest: ct,
 		workspace:  ws,
@@ -155,6 +157,7 @@ func (ct *Runner) TestDependencies() ([]string, error) {
 func (ct *Runner) retrieveCmd(ctx context.Context, out io.Writer, command string, imageTag string) (*exec.Cmd, error) {
 	var cmd *exec.Cmd
 	// We evaluate the command with a shell so that it can contain env variables.
+
 	if runtime.GOOS == Windows {
 		cmd = exec.CommandContext(ctx, "cmd.exe", "/C", command)
 	} else {
@@ -190,6 +193,14 @@ func (ct *Runner) getEnv(imageTag string) ([]string, error) {
 	}
 
 	envs = append(envs, util.OSEnviron()...)
+
+	// add minikube docker env vars to command env context if minikube cluster detected
+	localDaemon, err := docker.NewAPIClient(ct.cfg)
+	if err != nil {
+		return nil, fmt.Errorf("getting docker client information: %w", err)
+	}
+	envs = append(envs, localDaemon.ExtraEnv()...)
+
 	return envs, nil
 }
 
