@@ -24,6 +24,7 @@ import (
 	"runtime"
 	"testing"
 
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/docker"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner/runcontext"
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
@@ -31,6 +32,10 @@ import (
 	testEvent "github.com/GoogleContainerTools/skaffold/testutil/event"
 )
 
+func fakeLocalDaemonWithExtraEnv(extraEnv []string) docker.LocalDaemon {
+	return docker.NewLocalDaemon(&testutil.FakeAPIClient{}, extraEnv, false, nil)
+}
+
 func TestNewCustomTestRunner(t *testing.T) {
 	testutil.Run(t, "Testing new custom test runner", func(t *testutil.T) {
 		if runtime.GOOS == Windows {
@@ -38,6 +43,10 @@ func TestNewCustomTestRunner(t *testing.T) {
 		} else {
 			t.Override(&util.DefaultExecCommand, testutil.CmdRun("sh -c echo Running Custom Test command."))
 		}
+		t.Override(&docker.NewAPIClient, func(cfg docker.Config) (docker.LocalDaemon, error) {
+			return fakeLocalDaemonWithExtraEnv([]string{}), nil
+		})
+
 		tmpDir := t.NewTempDir().Touch("test.yaml")
 
 		custom := latestV1.CustomTest{
@@ -107,6 +116,9 @@ func TestCustomCommandError(t *testing.T) {
 				command = test.expectedWindowsCmd
 			}
 			t.Override(&util.DefaultExecCommand, testutil.CmdRunErr(command, fmt.Errorf(test.expectedError)))
+			t.Override(&docker.NewAPIClient, func(cfg docker.Config) (docker.LocalDaemon, error) {
+				return fakeLocalDaemonWithExtraEnv([]string{}), nil
+			})
 
 			testCase := &latestV1.TestCase{
 				ImageName:   "image",
@@ -254,6 +266,7 @@ func TestGetEnv(t *testing.T) {
 		testContext string
 		environ     []string
 		expected    []string
+		extraEnv    []string
 	}{
 
 		{
@@ -269,11 +282,25 @@ func TestGetEnv(t *testing.T) {
 			testContext: "/some/path",
 			expected:    []string{"IMAGE=gcr.io/image/tag:anothertag", "TEST_CONTEXT=/some/path", "PATH=/path", "HOME=/root"},
 		},
+		{
+			description: "make sure minikube docker env is applied when minikube profile present",
+			tag:         "gcr.io/image/tag:anothertag",
+			environ:     []string{"PATH=/path", "HOME=/root"},
+			testContext: "/some/path",
+			expected: []string{"IMAGE=gcr.io/image/tag:anothertag", "TEST_CONTEXT=/some/path", "PATH=/path", "HOME=/root",
+				"DOCKER_CERT_PATH=/path/.minikube/certs", "DOCKER_HOST=tcp://192.168.49.2:2376",
+				"DOCKER_TLS_VERIFY=1", "MINIKUBE_ACTIVE_DOCKERD=minikube"},
+			extraEnv: []string{"DOCKER_CERT_PATH=/path/.minikube/certs", "DOCKER_HOST=tcp://192.168.49.2:2376",
+				"DOCKER_TLS_VERIFY=1", "MINIKUBE_ACTIVE_DOCKERD=minikube"},
+		},
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			t.Override(&util.OSEnviron, func() []string { return test.environ })
 			t.Override(&testContext, func(string) (string, error) { return test.testContext, nil })
+			t.Override(&docker.NewAPIClient, func(cfg docker.Config) (docker.LocalDaemon, error) {
+				return fakeLocalDaemonWithExtraEnv(test.extraEnv), nil
+			})
 			tmpDir := t.NewTempDir().Touch("test.yaml")
 
 			custom := latestV1.CustomTest{
