@@ -41,8 +41,8 @@ func expandingFilePathsErr(err error) error {
 	)
 }
 
-func dockerPullImageErr(fqn string, err error) (string, error) {
-	return "", sErrors.NewError(err,
+func dockerPullImageErr(fqn string, err error) error {
+	return sErrors.NewError(err,
 		proto.ActionableErr{
 			Message: fmt.Sprintf("unable to docker pull image %s: %s", fqn, err),
 			ErrCode: proto.StatusCode_TEST_IMG_PULL_ERR,
